/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 1991-2008 OpenCFD Ltd.
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM; if not, write to the Free Software Foundation,
    Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Global
    kOmegaWallViscosity

Description
    Calculate wall viscosity from wall-functions.

\*---------------------------------------------------------------------------*/

{
    scalar Cmu25 = pow(Cmu_.value(), 0.25);

    const fvPatchList& patches = mesh_.boundary();

    forAll(patches, patchi)
    {
        const fvPatch& curPatch = patches[patchi];

        if (isType<wallFvPatch>(curPatch))
        {
            const scalarField& nuw = nu().boundaryField()[patchi];
            scalarField& nutw = nut_.boundaryField()[patchi];

            scalarField magFaceGradU =
                mag(U_.boundaryField()[patchi].snGrad());
	    scalarField Ufield=mag(U_.boundaryField()[patchi]);
            forAll(curPatch, facei)
            {
                label faceCelli = curPatch.faceCells()[facei];

                scalar yPlus = Cmu25*y_[faceCelli]*sqrt(k_[faceCelli])/nuw[facei];

		scalar Gamma = (0.01 * pow(yPlus,4))/ (1+5* yPlus);
		//		scalar Psi2=1.0 - (y_[faceCelli] / ((sqrt(k_[faceCelli])*kappa_.value()*Cmu25*Ufield[facei])+0.000001));
		
		// Bredberg
// 		scalarField Ret=nutw/nuw;
// 		scalarField f = exp(-Ret,1.7);

		//// Switch-WallTreatment		
//                 if (yPlus > yPlusLam_)
//                 {
// 		    nutw[facei] = nuw[facei] + nuw[facei]*yPlus*kappa_.value()/log(E_.value()*yPlus);
//                 }

		//V1
		//nutw[facei] = nutw[facei]*exp(-Gamma)+(nuw[facei] + nuw[facei]*yPlus*kappa_.value()/log(E_.value()*yPlus))*exp(-1/Gamma);
		//V2
		//nutw[facei] = nuw[facei]*exp(-Gamma)+(nuw[facei] + nuw[facei]*yPlus*kappa_.value()/log(E_.value()*yPlus))*exp(-1/Gamma);
		//V3
		nutw[facei] = nuw[facei]*exp(-Gamma)+(nuw[facei]+nuw[facei]*yPlus*kappa_.value()/log(E_.value()*yPlus))*exp(-1/Gamma);
//                 else
//                 {
// 		    //                    nutw[facei] = 0.0;
// 		    // nutw=nut
//                 }
            }
        }
    }
}


// ************************************************************************* //
